#' Calculate geographic centroids for points
#'
#' Using \code{\link[rgeos]{gCentroid}}. Note this function does not take earth sphericity into account. So it's a good idea to provide the spatial object \code{x} in a planar projection. \code{\link[geosphere]{centroid}} uses Mercator, but warns about problems close to the poles.
#'
#' @param x A spatial object.
#' @param group.var character Optional. Name of grouping variable in \code{x} to calculate centroids for each group separately.
#'
#' @return A SpatialPoints object with the centroids coordinates.
#' @importFrom rgeos gCentroid
#' @export
#'
#' @seealso \code{\link[rgeos]{gCentroid}}, \code{\link[geosphere]{centroid}}, \code{\link[spatstat]{centroid.owin}}
#'
centroid_points <- function(x, group.var = NULL) {

  if (is.null(group.var)) {

    ctrs <- rgeos::gCentroid(x)

  } else {

    vble <- x@data[, group.var]
    ctrs <- lapply(unique(vble), function(z) {rgeos::gCentroid(x[vble == z, ])})
    ctrs <- do.call("rbind", ctrs)
    #ctrs <- data.frame(group = unique(vble), x = ctrs[,1], y = ctrs[,2])

  }

  ctrs

}
