
#' Make climatic dataset
#'
#' Assemble climatic dataset combining temperature, precipitation and SST. These datasets must have created before by rendering 'climate_data_preparation.Rmd' (see project makefile).
#'
#' @return File "clidata.csv" written to disk (data folder)
#' @export
#' @import readr
#' @import dplyr
#'

make_clim_dataset <- function() {

  ## Load climate datasets

  tmp <- readr::read_csv("data/region.avg_tmp.csv")
  pre <- readr::read_csv("data/region.avg_pre.csv")
  sst <- readr::read_csv("data/region.avg_sst.csv")


  ## Join tmp and pre first

  # First, rename cli variables
  names(tmp) <- gsub("cli", "T", names(tmp))
  names(pre) <- gsub("cli", "P", names(pre))
  names(sst) <- gsub("cli", "T", names(sst))


  # Merge tmp and pre first
  pre2merge <- dplyr::select(pre, study.sp.vble.reg.id, starts_with("P", ignore.case = FALSE))
  clidata <- merge(tmp, pre2merge, by = "study.sp.vble.reg.id")

  # Now merge sst
  clidata <- dplyr::bind_rows(clidata, sst)

  ## Rearrange dataset
  clidata <- clidata %>%
    move_columns("study.sp.vble.reg.id", after = "study.sp.vble.id") %>%
    move_columns("npop.centre", after = "npop.margin") %>%
    move_columns("Tmean.centre", after = "Tmean") %>%
    move_columns("Tmean.dif", "Tmean.centre") %>%
    move_columns("Tsd.centre", after = "Tsd") %>%
    move_columns("Ttrend.dif", after = "Ttrend.se.centre") %>%
    move_columns("Pmean.centre", after = "Pmean") %>%
    move_columns("Psd.centre", after = "Psd") %>%
    move_columns("Pmean.dif", after = "Pmean.centre") %>%
    move_columns("Ptrend.dif", after = "Ptrend.se.centre")


  write_csv(clidata, "data/clidata.csv")



}

